erebos-0.1.9: Decentralized messaging and synchronization
Safe HaskellNone
LanguageHaskell2010

Erebos.Storage.Merge

Synopsis

Documentation

class Storable (Component a) => Mergeable a where Source #

Associated Types

type Component a Source #

Instances

Instances details
Mergeable ChatroomState Source # 
Instance details

Defined in Erebos.Chatroom

Associated Types

type Component ChatroomState 
Instance details

Defined in Erebos.Chatroom

Mergeable Contact Source # 
Instance details

Defined in Erebos.Contact

Associated Types

type Component Contact 
Instance details

Defined in Erebos.Contact

Mergeable DirectMessageThreads Source # 
Instance details

Defined in Erebos.Message

Associated Types

type Component DirectMessageThreads 
Instance details

Defined in Erebos.Message

Mergeable a => Mergeable (Set a) Source # 
Instance details

Defined in Erebos.Set

Associated Types

type Component (Set a) 
Instance details

Defined in Erebos.Set

type Component (Set a)
Mergeable (Maybe ComposedIdentity) Source # 
Instance details

Defined in Erebos.Identity

Associated Types

type Component (Maybe ComposedIdentity) 
Instance details

Defined in Erebos.Identity

Mergeable [Stored Object] Source # 
Instance details

Defined in Erebos.Storage.Merge

Associated Types

type Component [Stored Object] 
Instance details

Defined in Erebos.Storage.Merge

merge :: Mergeable a => [Stored (Component a)] -> a Source #

data Generation Source #

Instances

Instances details
Show Generation Source # 
Instance details

Defined in Erebos.Storage.Internal

Eq Generation Source # 
Instance details

Defined in Erebos.Storage.Internal

generations :: Storable a => [Stored a] -> [Set (Stored a)] Source #

Returns list of sets starting with the set of given objects and intcrementally adding parents.

ancestors :: Storable a => [Stored a] -> Set (Stored a) Source #

Returns set containing all given objects and their ancestors

walkAncestors :: (Storable a, Monoid m) => (Stored a -> m) -> [Stored a] -> m Source #

findProperty :: Storable a => (a -> Maybe b) -> [Stored a] -> [b] Source #

findPropertyFirst :: Storable a => (a -> Maybe b) -> [Stored a] -> Maybe b Source #